@@ -164,41 +164,39 @@ def generateEventString(eventInfo):
         if eventInfo["schedule"] in [i["every_minute"], i["hourly"],
                                      i["daily"], i["once_a_month"], 
                                      i["end_of_month"], i["once_a_year"]]:
-            eventString = (eventInfo["schedule"] + " " +
+            eventTitle = (eventInfo["schedule"] + " " +
                            eventInfo["type"].lower() +
                            " starting on " + 
                            dt.strftime("%d.%m.%Y") +
-                           " at " + dt.strftime("%H:%M") +
-                           ": " + eventInfo["title"])
+                           " at " + dt.strftime("%H:%M") + ":")
         elif eventInfo["schedule"] in [i["weekly"], i["biweekly"]]:
             days = ""
             for day in eventInfo["weekdays"]:
-                days = days + day + ","
+                days = days + day[0:3] + ", "
             days = days[0:len(days)-1]
-            eventString = (eventInfo["schedule"] + " " +
+            eventTitle = (eventInfo["schedule"] + " " +
                            eventInfo["type"].lower() + " every " +
-                           days + " at " + dt.strftime("%H:%M") +
-                           ": " + eventInfo["title"])
+                           days + " at " + dt.strftime("%H:%M") + ":")
         elif eventInfo["schedule"] in [i["in"], i["next"], 
                                        i["tomorrow"], i["only_once"]]:
-            eventString = (eventInfo["type"].lower() +
+            eventTitle = (eventInfo["type"] +
                            " on " + 
                            dt.strftime("%d.%m.%Y") +
-                           " at " + dt.strftime("%H:%M") +
-                           ": " + eventInfo["title"])
+                           " at " + dt.strftime("%H:%M") + ":")
         elif eventInfo["schedule"] == i["cron"]:
             c = ""
             for part in eventInfo["cron"]:
                 c = c + " " + part
             c = c.lstrip()
-            eventString = (eventInfo["type"].lower() + " with cron mask: " +
-                           c + ": " + eventInfo["title"])
+            eventTitle = (eventInfo["type"].lower() + 
+                           " with cron mask: " + c + ":")
         elif eventInfo["schedule"] == i["date"]:
-            eventString = (eventInfo["type"].lower() + " with date string: "
-                           + eventInfo["date"] + ": " + eventInfo["title"])
+            eventTitle = (eventInfo["type"].lower() + " with date string: "
+                           + eventInfo["date"] + ":")
     except KeyError:
-        return "Corrupt job file, please delete or re-save me!"
-    return eventString
+        return "Corrupt job file", "Please delete or re-save me!"
+    eventContent = eventInfo["title"]
+    return eventTitle, eventContent
 
 def interpretCronString(string):
     """Checks if the string entered is valid and puts it in a list"""
