@@ -8,6 +8,17 @@ import datetime
 from PySide import QtCore, QtGui, QtMaemo5
 import alarmed_backend
 
+class EventWidget(QtGui.QWidget):
+    def __init__(self, title, content, parent=None):
+        """A single event with title and content for the list"""
+        QtGui.QWidget.__init__(self, parent)
+        self.title = QtGui.QLabel(title)
+        self.content = QtGui.QLabel(content)
+        self.allVBox = QtGui.QVBoxLayout()
+        self.allVBox.addWidget(self.title)
+        self.allVBox.addWidget(self.content)
+        self.setLayout(self.allVBox)
+
 class AlarmedGUI(QtGui.QWidget):
     def __init__(self, parent=None):
         """Main window displaying the list of events and 3 buttons"""
@@ -40,19 +51,24 @@ class AlarmedGUI(QtGui.QWidget):
         #read the available fields from the backend
         self.fields = alarmed_backend.loadFieldsDict()
         self.weekdays = []
-        
+
     def showError(self, msg=""):
         """Shows a QMaemo5InformationBox containing the error message"""
         banner = QtMaemo5.QMaemo5InformationBox()
         banner.information(self, msg, 3000)
 
-    def addEventToList(self, eventInfo):
+    def addEventToList(self, eventInfo, editing=False):
         """Adds a QListWidgetItem to the list of events"""
-        newEventString = alarmed_backend.generateEventString(eventInfo)
-        newEvent = QtGui.QListWidgetItem(newEventString)
+        if editing:
+            self.eventList.removeItemWidget(
+                           self.eventList.currentItem())
+        newEventTitle, newEventContent = alarmed_backend.generateEventString(eventInfo)
+        newEvent = QtGui.QListWidgetItem() #(newEventString)
+        newEventWidget = EventWidget(newEventTitle, newEventContent)
         newEvent.eventInfo = eventInfo
         self.eventList.addItem(newEvent)
-        
+        self.eventList.setItemWidget(newEvent, newEventWidget)
+
     def removeEvent(self):
         """Calls backend to remove an event"""
         if (self.eventList.currentItem()):
@@ -62,7 +78,7 @@ class AlarmedGUI(QtGui.QWidget):
              self.eventList.currentItem())
         else:
             self.showError('''<font color="#000000">Select an item first</font>''')
-            
+
     def editEvent(self):
         """Same as a normal addition, but will delete existing"""
         if (self.eventList.currentItem()):
@@ -74,7 +90,7 @@ class AlarmedGUI(QtGui.QWidget):
         """Present a dialog to set and edit events"""
         self.newEventDialog = QtGui.QDialog(self)
         self.newEventDialog.setWindowTitle("Add event")
-        
+
         #There are three rows of widgets
         self.row1 = QtGui.QHBoxLayout(self)
         self.row2 = QtGui.QHBoxLayout(self)
@@ -84,7 +100,7 @@ class AlarmedGUI(QtGui.QWidget):
         self.container.addLayout(self.row2)
         self.container.addLayout(self.row3)
         self.newEventDialog.setLayout(self.container)
-        
+
         #picker for event types
         self.typePicker = QtGui.QComboBox()
         for i in self.fields["types"]:
@@ -202,7 +218,7 @@ class AlarmedGUI(QtGui.QWidget):
             self.dateWidget.setCurrentDate(QtCore.QDate.fromString(
                             dateTime.toString("ddMMyyyy"),"ddMMyyyy"))
             self.timeWidget.setCurrentTime(QtCore.QTime.fromString(
-                            dateTime.toString("hhmm"),"hhmm"))              
+                            dateTime.toString("hhmm"),"hhmm"))
             #adjust selected weekdays
             try: self.weekdays = (item.eventInfo["weekdays"])
             except KeyError: pass
@@ -246,10 +262,10 @@ class AlarmedGUI(QtGui.QWidget):
         t = self.fields["types"]
         if type == t["alarm_type"]:
             self.execPicker.hide()
-            self.builtinPicker.hide()  
-            self.profilePicker.hide() 
-            self.execSavePresetButton.hide() 
-            self.execPresetPicker.hide() 
+            self.builtinPicker.hide()
+            self.profilePicker.hide()
+            self.execSavePresetButton.hide()
+            self.execPresetPicker.hide()
         elif type == t["exec_type"]:
             self.builtinPicker.hide()
             self.execPicker.show()
@@ -260,13 +276,13 @@ class AlarmedGUI(QtGui.QWidget):
             self.execPicker.hide()
             self.builtinPicker.show()
             self.profilePicker.hide()
-            self.execSavePresetButton.hide() 
-            self.execPresetPicker.hide() 
+            self.execSavePresetButton.hide()
+            self.execPresetPicker.hide()
         elif type == t["profile_type"]:
             self.execPicker.hide()
             self.builtinPicker.hide()
-            self.execSavePresetButton.hide() 
-            self.execPresetPicker.hide() 
+            self.execSavePresetButton.hide()
+            self.execPresetPicker.hide()
             self.profilePicker.show()
             self.profilePicker.clear()
             profiles = alarmed_backend.getAvailableProfiles()
@@ -393,7 +409,7 @@ class AlarmedGUI(QtGui.QWidget):
             self.timePicker.hide()
             self.cronPicker.hide()
             self.datesyntaxPicker.show()
-            
+
     def pickPreset(self):
         """Dialog for loading and deleting presets"""
         self.presetDialog = QtGui.QDialog()
@@ -418,7 +434,7 @@ class AlarmedGUI(QtGui.QWidget):
         self.presetDialogHBox.addLayout(self.presetDialogVBox)
         self.presetDialog.setLayout(self.presetDialogHBox)
         self.presetDialog.exec_()
-    
+
     def loadPresetList(self):
         self.presetList.clear()
         presets = alarmed_backend.loadPresetList()
@@ -426,7 +442,7 @@ class AlarmedGUI(QtGui.QWidget):
             addedPreset = QtGui.QListWidgetItem(preset[0])
             addedPreset.preset = preset
             self.presetList.addItem(addedPreset)
-    
+
     def usePreset(self):
         if (self.presetList.currentItem()):
             self.titlePicker.setText(
@@ -436,7 +452,7 @@ class AlarmedGUI(QtGui.QWidget):
             self.presetDialog.accept()
         else:
             self.showError('''<font color="#000000">Select an item first</font>''')
-        
+
     def deletePreset(self):
         """Calls backend to remove a preset """
         if (self.presetList.currentItem()):
@@ -512,7 +528,7 @@ class AlarmedGUI(QtGui.QWidget):
         if self.satBox.isChecked(): self.weekdays.append(w["sat"])
         if self.sunBox.isChecked(): self.weekdays.append(w["sun"])
         self.weekdayDialog.accept()
-    
+
     def saveEvent(self):
         """takes the GUI input and prepares it for the backend"""
         if self.editing:
@@ -575,7 +591,7 @@ class AlarmedGUI(QtGui.QWidget):
             s = str(self.cronPicker.text())
             status, cronstring = alarmed_backend.interpretCronString(s)
             if not status:
-                self.showError('''<font color="#000000">''' + 
+                self.showError('''<font color="#000000">''' +
                                cronstring + '''</font>''')
                 return False
             td = datetime.datetime.today()
@@ -598,7 +614,7 @@ class AlarmedGUI(QtGui.QWidget):
             dateTime.setDate(sdate)
             dateTime.setTime(stime)
             eventInfo["ttime"] = int(dateTime.toTime_t())
-            
+
         type = self.typePicker.currentText()
         content = ""
         if type == t["exec_type"]:
@@ -618,15 +634,8 @@ class AlarmedGUI(QtGui.QWidget):
             self.showError('''<font color="#000000">Please pick a date & time in the future</font>''')
             return False
         #add event to gui list
-        eventString = alarmed_backend.generateEventString(eventInfo)
-        if self.editing:
-            self.eventList.currentItem().setText(eventString)
-        else:
-            newEvent = QtGui.QListWidgetItem(eventString)
-        if self.editing:
-            self.eventList.currentItem().eventInfo = eventInfo
-        else:
-            self.addEventToList(eventInfo)
+        self.addEventToList(eventInfo, self.editing)
+        
         self.newEventDialog.accept()
 
 app = QtGui.QApplication(sys.argv)
